/* ==================================================================
   File:        config.h
   Author:      Steve Monks
   Description:
	Configuration module

 	$Id: config.h,v 1.5 2006/04/09 19:51:53 Steve Exp $
	$Log: config.h,v $
	Revision 1.5  2006/04/09 19:51:53  Steve
	Version 3.6
	Added logarithmic volume control
	Added diagnostic logging
	
	Revision 1.4  2006/02/04 20:59:44  Steve
	Initial import of readme.html
	
	Added gapless mode (for evaluation purposes)
	
	Revision 1.3  2006/01/29 21:33:57  Steve
	Added an adjustment for the number of output buffers
	Removed buffer size radio buttons and replaced with sliders
	Now deletes and recreates the KSCore object when a new track starts after changing the settings
	
	Revision 1.2  2006/01/03 21:46:13  Steve
	Initial import of V3.0.
	
	This is a complete rewrite of the plugin and Kernel streaming code.
	The only code retained from the previous 2.x version is the Microsoft
	sample code and the filter enumeration.
	
	Revision 1.1.1.1  2006/01/02 12:16:11  Steve
	Initial import
	
	Revision 1.1  2005/12/27 01:20:01  Steve
	Added Oversampling for <48KHz 16 bit audio
	Significant re-org and clean up of code
	
================================================================== */

#ifndef _CONFIG_H
#define _CONFIG_H

class Config {
private:
	char file_name[MAX_PATH+1];

	void ReadString(char *name,char *data, int mlen);
	void ReadInt(char *name,int *v);
	void WriteString(char *name, char *data);
	void WriteInt(char *name, int v);

	void Read(void);

public:
	char out_name[MAX_PATH+1];
	int volume_enabled;
	int gapless_enabled;
	int input_buffer_size;
	int output_buffer_size;
	int output_buffer_cnt;
	int logging_enabled;
	int logarithmic_volume;
		
	Config(void);			// set config defaults and load current settings from file
	void Defaults(void);	// restores default configuration
	void Write(void);		// write current settings to config file
};

#endif
